==> JAQK-0.0.2.3.tar.gz: JAQK-0.0.2.3/README.md <==
# Welcome to JAQK financial report package
> A light and useful toolkit developed for financial report getter and basic analysis and calculations.

> It starts with an assignment, proceeds with deadlines, and grows with passions. - Hanbo Guo

_Author: Hanbo Guo_

_Facility: High School Afflicated to Renmin University of China_

_Contact: hbopublic@163.com_


## What's this

**JAQK** is a Python tookit providing light and robust data collection and data processing for quantitative analysis for US stocks. JAQK aims to tackle the problem of gathering financial data for high school students, and we hope JAQK can help some basic level of quantitative analysis. 

## Installations
For quick installation with **PyPI**:
```sh
# PyPI 
pip install jaqk
```
and you can **upgrade** the package with:
```sh
# PyPI upgrade
pip install jaqk --upgrade
```
You can also **set up** the package after downloading the package from this site:
```sh
# install after downloading
cd (PATH of the download, change to yours) (e.g. macOS: /Users/hanbo/Downloads/JAQK-master; windows: C:\Users\hanbo\Desktop\JAQK-master) 
python setup.py install
```

## Dependency
- Python 3.4 or more
- For data collection
  - [requests](https://2.python-requests.org//en/master/)
  - [pyquery](https://pyquery.readthedocs.io/en/latest/)
  - [aiohttp](https://aiohttp.readthedocs.io/en/stable/)
  - [selenium](https://selenium-python.readthedocs.io) (optional; it will be changed to pypeppter)
  - [openpyxl](https://openpyxl.readthedocs.io/en/stable/)
- For data processing
  - [pandas](http://pandas.pydata.org/ "pandas")
  - [numpy](http://www.numpy.org)
- Other necessities
  - [pysimplegui](https://pysimplegui.readthedocs.io/en/latest/)
  - unittest >= 3.2.0
  
## Documentation
The official documentation is hosted by [github.io]() (Nothing there right now...).
  
## Getting help
For usage questions, the best place to go to is [StackOverflow](https://stackoverflow.com/questions/tagged/JAQK);
Further, general questions and discussions can also take place on the github [issues section](https://github.com/Haannbboo/JAQK/issues).

If you have **ANY** detailed question about the plan/design/develop of this package, feel free to contact me through my [email](hbopublic@163.com).

## Previous Updates

All changes (pushes) have been recorded [here](https://github.com/Haannbboo/JAQK/blob/master/HISVERSION.md). Click for more details.

==> JAQK-0.0.3.1.tar.gz: JAQK-0.0.3.1/README.md <==
# Welcome to JAQK financial data module
> A light and useful toolkit developed for financial report getter and basic analysis and calculations.

> It starts with an assignment, proceeds with deadlines, and grows with passions. - Hanbo Guo

_Author: Hanbo Guo_

_Facility: High School Afflicated to Renmin University of China_

_Contact: hbopublic@163.com_


## What's this

**JAQK** is a Python tookit providing light and robust **data collection** and **data processing** for quantitative analysis for US stocks. JAQK aims to tackle the problem of gathering financial data for **high school students**, and we hope JAQK can help basic level of quantitative analysis. 

## Installations
For quick installation with **PyPI**:
```sh
# PyPI 
pip install jaqk
```
and you can **upgrade** the package with:
```sh
# PyPI upgrade
pip install jaqk --upgrade
```
You can also **set up** the package after downloading the package from this site:
```sh
# install after downloading
cd (PATH of the download, change to yours) (e.g. macOS: /Users/hanbo/Downloads/JAQK-master; windows: C:\Users\hanbo\Desktop\JAQK-master) 
python setup.py install
```

## Dependency
- Python 3.4 or more
- For data collection
  - [requests](https://2.python-requests.org//en/master/)
  - [pyquery](https://pyquery.readthedocs.io/en/latest/)
  - [aiohttp](https://aiohttp.readthedocs.io/en/stable/)
  - [selenium](https://selenium-python.readthedocs.io) (optional; it will be changed to pypeppter)
  - [openpyxl](https://openpyxl.readthedocs.io/en/stable/)
- For data processing
  - [pandas](http://pandas.pydata.org/ "pandas")
  - [numpy](http://www.numpy.org)
- Other necessities
  - [pysimplegui](https://pysimplegui.readthedocs.io/en/latest/)
  - unittest >= 3.2.0
  
## Documentation
The official documentation is hosted by [github.io]() (Nothing there right now...).
  
## Getting help
For usage questions, the best place to go to is [StackOverflow](https://stackoverflow.com/questions/tagged/JAQK);
Further, general questions and discussions can also take place on the github [issues section](https://github.com/Haannbboo/JAQK/issues).

If you have **ANY** detailed question about the plan/design/develop of this package, feel free to contact me through my [email](hbopublic@163.com).

## Previous Updates

All changes (pushes) have been recorded [here](https://github.com/Haannbboo/JAQK/blob/master/HISVERSION.md). Click for more details.
